# Licensed under the BSD 3-Clause License   
# Copyright (C) 2021 GeospaceLab (geospacelab)
# Author: Lei Cai, Space Physics and Astronomy, University of Oulu

__author__ = "Lei Cai"
__copyright__ = "Copyright 2021, GeospaceLAB"
__credits__ = ["Lei Cai"]
__license__ = "BSD-3-Clause License"
__version__ = "0.8.8"
__maintainer__ = "Lei Cai"
__email__ = "lei.cai@oulu.fi"
__status__ = "Developing"
__docformat__ = "reStructureText"


import geospacelab.config as config
from geospacelab.datahub import DataHub, DatasetUser
from geospacelab.visualization.mpl import create_figure as figure
from geospacelab.visualization.mpl.dashboards import TSDashboard
from geospacelab.visualization.mpl.geomap.geodashboards import GeoDashboard
import geospacelab.visualization.mpl.geomap.geopanels as geopanels




